@@ -1,3 +1,5 @@
+from typing import List
+
 import requests
 
 from .exceptions import (
@@ -14,6 +16,7 @@ def infer(
     raster: bytes,
     api_key: str,
     calc_metrics: bool,
+    raster_maxes: List[int],
     host: str,
     port: int,
     endpoint: str,
@@ -65,7 +68,14 @@ def infer(
     """
     rasters = {"submission": raster}
     qc = {True: "yes", False: "no"}
-    headers = {"in1-api-key": api_key, "in1-calc-metrics": qc.get(calc_metrics, "yes")}
+    headers = {
+        "in1-api-key": api_key,
+        "in1-calc-metrics": qc.get(calc_metrics, "yes"),
+        "in1-max-blue": str(raster_maxes[0]),
+        "in1-max-green": str(raster_maxes[1]),
+        "in1-max-red": str(raster_maxes[2]),
+        "in1-max-infrared": str(raster_maxes[3]),
+    }
 
     protocol = "https" if port == 443 else "http"
     target = f"{protocol}://{host}:{port}/v{version}/{endpoint}"
